#include "demo_spi.h"
#include "demo_systick.h"

/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/
/*****************************************************************************
 ** \brief	SPI_M95256_Start		
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void SPI_M95256_Start(void)
{
	SPI_SSOutputCmd(SSP0,SPI_NSSInternalSoft_Low);
}
/*****************************************************************************
 ** \brief	SPI_M95256_Stop
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void SPI_M95256_Stop(void)
{
	SPI_SSOutputCmd(SSP0,SPI_NSSInternalSoft_High);
}
/*****************************************************************************
 ** \brief	SPI_Transmit
 **			
** \param [in] SendData: ͵ֵ
 ** \return  16bit ȡֵ
 ** \note	
*****************************************************************************/
uint32_t  SPI_Transmit(uint32_t  Data)
{
	while(SPI_GetFlagStatus(SSP0,SPI_STAT_BSY));			
	while(!SPI_GetFlagStatus(SSP0,SPI_STAT_TFE));
	SPI_SendDataNBit(SSP0,Data);
	while(!SPI_GetFlagStatus(SSP0,SPI_STAT_RNE));
	return (SPI_ReceiveDataNBit(SSP0));		
}
/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/


/***************************************************************************
 ** \brief	 SPI_M95256_Write
 **			 
 ** \param [in]  addr: 
 **				 buf:
 ** \return 
 ** \note
***************************************************************************/
void SPI_M95256_Write(uint32_t addr, uint32_t buf)
{
	uint32_t temp;
	
	SPI_M95256_Start();
	SPI_Transmit(M95256_WREN);
	SPI_M95256_Stop();			
	for(temp=2;temp>0;temp--);	
	
	SPI_M95256_Start();
	SPI_Transmit(M95256_WRITE);	
	SPI_Transmit(addr>>16);
	SPI_Transmit(addr>>8);
	SPI_Transmit(addr);		
	SPI_Transmit(buf);	
	SPI_M95256_Stop();	

	for(temp=2;temp>0;temp--);	
	SPI_M95256_Start();
	SPI_Transmit(M95256_WRDI);
	SPI_M95256_Stop();		

}
/***************************************************************************
 ** \brief	 SPI_M95256_Read_Data
 **			
** \param [in]  addr :   
 ** \return 8bit Data
 ** \note
***************************************************************************/
uint32_t SPI_M95256_Read_Data(uint32_t addr)
{
	uint32_t temp;
	SPI_M95256_Start();
	SPI_Transmit(M95256_READ);
	SPI_Transmit(addr>>16);	
	SPI_Transmit(addr>>8);
	SPI_Transmit(addr);
	temp = SPI_Transmit(0x00);		
	SPI_M95256_Stop();
	return temp;
}

/***************************************************************************
 ** \brief	 SPI_M95256_Read_SFR
 **			
 ** \param [in]  cmd:	
 ** \return 8bit Data
 ** \note
***************************************************************************/
uint32_t  SPI_M95256_Read_SFR(uint32_t cmd)
{
	uint8_t temp;
	SPI_M95256_Start();
	SPI_Transmit(cmd);
	temp = SPI_Transmit(0x00);
	SPI_M95256_Stop();	
	return temp;	
}





void SPI_ConfigMaster(void)
{
    SPI_InitTypeDef SPI0_InitType;

    SYS_IOPConfig(E_P01,P01SPI0_SS);
    SYS_IOPConfig(E_P05,P05SPI0_MOSI);
    SYS_IOPConfig(E_P06,P06SPI0_MISO);
    SYS_IOPConfig(E_P12,P12SPI0_CLK);

    SPI_DeInit(SSP0);

    SYS_APBPeriphClockCmd(SYS_APB_SSP0CE,ENABLE);
    SPI_StructInit(&SPI0_InitType);
    SPI0_InitType.SPI_Mode      = SPI_Mode_Master;
    SPI0_InitType.SPI_DataSize  = SPI_DataSize_8b;
    SPI0_InitType.SPI_CPO       = SPI_CPO_Low;
	  SPI0_InitType.SPI_CPH       = SPI_CPH_1Edge;
    SPI0_InitType.SPI_NSS       = SPI_NSS_Soft;
    SPI_Init(SSP0,&SPI0_InitType);

    SPI_SetClockFreq(SSP0,10000);
    SPI_DataSizeConfig(SSP0,SPI_DataSize_8b);
    SPI_Cmd(SSP0,ENABLE);
	
    SPI_ITConfig(SSP0,SPI_IT_RxHalfFull | SPI_IT_OverTim,ENABLE);
    NVIC_ClearPendingIRQ(SSP0_IRQn);
    NVIC_EnableIRQ(SSP0_IRQn);
}

void SPI_ConfigSlaver(void)
{
    SPI_InitTypeDef SPI0_InitType;

    SYS_IOPConfig(E_P04,P04SPI0_SS);
    SYS_IOPConfig(E_P05,P05SPI0_MOSI);
    SYS_IOPConfig(E_P06,P06SPI0_MISO);
    SYS_IOPConfig(E_P12,P12SPI0_CLK);

    SPI_DeInit(SSP0);

    SYS_APBPeriphClockCmd(SYS_APB_SSP0CE,ENABLE);
    SPI_StructInit(&SPI0_InitType);
    SPI0_InitType.SPI_Mode      = SPI_Mode_Slave;
    SPI0_InitType.SPI_DataSize  = SPI_DataSize_16b;
    SPI0_InitType.SPI_CPO       = SPI_CPO_High;
	  SPI0_InitType.SPI_CPH       = SPI_CPH_2Edge;
    SPI0_InitType.SPI_NSS       = SPI_NSS_Hard;
    SPI_Init(SSP0,&SPI0_InitType);

    SPI_SetClockFreq(SSP0,1000);
    SPI_DataSizeConfig(SSP0,SPI_DataSize_16b);
    SPI_Cmd(SSP0,ENABLE);

    SPI_ITConfig(SSP0,SPI_IT_RxHalfFull | SPI_IT_OverTim,ENABLE);
    NVIC_ClearPendingIRQ(SSP0_IRQn);
    NVIC_EnableIRQ(SSP0_IRQn);
}



