/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file demo_epwm.c
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "demo_epwm.h"

/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/*****************************************************************************
 ** \brief	EPWM_Brake_ACMP0
 **			
 ** \param [in] none
 ** \return  none
 ** \note	
*****************************************************************************/
void EPWM_Brake_ACMP0(void)
{
	/*
	(1)EPWMģʽ
	*/
	EPWM_ConfigRunMode(  EPWM_COUNT_DOWN 		| 			/*¼ģʽ(ض)*/
						 EPWM_OCU_SYMMETRIC 	|			/*Գģʽ*/
						 EPWM_WFG_COMPLEMENTARYK   |		/*ģʽ*/
						 EPWM_OC_INDEPENDENT);				/*ģʽ*/
	/*
	(2)EPWMʱ
	*/
	SYS_EnablePeripheralClk(SYS_CLK_EPWM_MSK);				/*EPWMʱ*/
	
	EPWM_ConfigChannelClk( EPWM0, EPWM_CLK_DIV_1);			/*EPWM0ʱΪAPBʱӵ1Ƶ*/
	EPWM_ConfigChannelClk( EPWM2, EPWM_CLK_DIV_1);			/*EPWM2ʱΪAPBʱӵ1Ƶ*/
	EPWM_ConfigChannelClk( EPWM4, EPWM_CLK_DIV_1);			/*EPWM4ʱΪAPBʱӵ1Ƶ*/

	EPWM_ConfigChannelPeriod(EPWM0,  4800);					/*EPWM0ͨ = 4800/Fepwm = 100us*/
	EPWM_ConfigChannelPeriod(EPWM2,  4800);					/*EPWM2ͨ = 4800/Fepwm = 100us*/
	EPWM_ConfigChannelPeriod(EPWM4,  4800);					/*EPWM4ͨ = 4800/Fepwm = 100us*/

	EPWM_ConfigChannelSymDuty(EPWM0, 1200);					/*EPWM0ͨռձ = 25%*/
	EPWM_ConfigChannelSymDuty(EPWM2, 2400);					/*EPWM2ͨռձ = 50%*/	
	EPWM_ConfigChannelSymDuty(EPWM4, 3600);					/*EPWM4ͨռձ = 75%*/	

	EPWM_DisableDeadZone(EPWM_CH_0_MSK | EPWM_CH_1_MSK |
						 EPWM_CH_2_MSK | EPWM_CH_3_MSK |
						 EPWM_CH_4_MSK | EPWM_CH_5_MSK);	/*ر*/

	/*
	(3)EPWM
	*/
	EPWM_DisableReverseOutput( EPWM_CH_0_MSK | EPWM_CH_1_MSK |
							   EPWM_CH_2_MSK | EPWM_CH_3_MSK |
							   EPWM_CH_4_MSK | EPWM_CH_5_MSK );				/*رշ*/

	/*
	(4)EPWMطʽ
	*/
	EPWM_EnableAutoLoadMode(EPWM_CH_0_MSK | EPWM_CH_2_MSK | EPWM_CH_4_MSK );	/*ΪԶģʽ*/
	EPWM_ConfigLoadAndIntMode(EPWM0, EPWM_EACH_PERIOD_ZERO);			
	EPWM_ConfigLoadAndIntMode(EPWM2, EPWM_EACH_PERIOD_ZERO);
	EPWM_ConfigLoadAndIntMode(EPWM4, EPWM_EACH_PERIOD_ZERO);			/*صΪÿڵ*/

	/*
	(5)EPWMɲ
	*/
	EPWM_EnableFaultBrake(EPWM_BRK_ACMP0EE);			/*ACMP0ƽɲ*/
			
	EPWM_ConfigFaultBrakeLevel(EPWM_CH_0_MSK | EPWM_CH_2_MSK |EPWM_CH_4_MSK,0);
	EPWM_ConfigFaultBrakeLevel(EPWM_CH_1_MSK | EPWM_CH_3_MSK |EPWM_CH_5_MSK,1);
	EPWM_AllBrakeEnable();

	/*
	(6)ж
	*/
	EPWM_EnableBrakeInt();								/*ɲж*/		
	NVIC_EnableIRQ(EPWM_IRQn);
	/*
	(6)ȼ
	*/	
	NVIC_SetPriority(EPWM_IRQn,3);					/*ȼ0~3 0ߡ3*/
	
	/*
	(7)IO
	*/	
	SYS_SET_IOCFG(IOP22CFG, SYS_IOCFG_P22_EPWM0);		
	SYS_SET_IOCFG(IOP23CFG, SYS_IOCFG_P23_EPWM1);	
	SYS_SET_IOCFG(IOP24CFG, SYS_IOCFG_P24_EPWM2);	
	SYS_SET_IOCFG(IOP25CFG, SYS_IOCFG_P25_EPWM3);	
	SYS_SET_IOCFG(IOP17CFG, SYS_IOCFG_P17_EPWM4);	
	SYS_SET_IOCFG(IOP21CFG, SYS_IOCFG_P21_EPWM5);	
	
	EPWM_EnableOutput(EPWM_CH_0_MSK | EPWM_CH_1_MSK |
					  EPWM_CH_2_MSK | EPWM_CH_3_MSK |
					  EPWM_CH_4_MSK | EPWM_CH_5_MSK );

	/*
	(8)EPWM
	*/		
	EPWM_Start(EPWM_CH_0_MSK | EPWM_CH_2_MSK | EPWM_CH_4_MSK);
	
}


